JWT Error Types
This module contains error types used throughout the JWT library for handling various failure scenarios during JWT validation and processing.
Enums
- JWTError
- Possible errors when handling the JWT validation lifecycle.