JWT Data Models
This module contains data structures and types used for JWT processing including claims, signing algorithms, and validation components.
Primary types
JWTClaims: struct representing JWT claimsSigningAlgorithm: enum representing JWT signing algorithmsSigningKeyLength: enum representing JWT signing key length
Modules
- claim_
names - JWT available claims.
Structs
- JWTClaims
- The JWT decoded content. It consists of 2 key-value maps: one for the JWT header and another one for the JWT body.
Enums
- Signing
Algorithm - List of possible JWT signing algorithms. See JWT signing algorithms specification (RFC 7518)
- Signing
KeyLength - List of possible JWT signing key lengths. Note: not all algorithms support all key lengths
Traits
- Value
Retrieval - Trait to be implemented for any sized data type for which a JWT claim wants to casted when
retrieved by the
JWTClaims::get_claimmethod.