JWTClaims

Struct JWTClaims 

pub struct JWTClaims { /* private fields */ }
The JWT decoded content. It consists of 2 key-value maps: one for the JWT header and another one for the JWT body.

Implementations

Source

impl JWTClaims

pub fn new( expiration: Option<DateTime<Utc>>, not_before: Option<DateTime<Utc>>, issued_at: Option<DateTime<Utc>>, claims: HashMap<String, Value>, headers: HashMap<String, Value>, ) -> Result<Self, JWTError>

Create a new JWTClaims with the given expiration, not before, issued at, claims and headers.

pub fn audience(&self) -> Option<Result<Vec<String>, JWTError>>

Get the audience claim.

pub fn not_before(&self) -> Option<DateTime<Utc>>

Get the not before claim.

pub fn expiration(&self) -> Option<DateTime<Utc>>

Get the expiration claim.

pub fn issued_at(&self) -> Option<DateTime<Utc>>

Get the issued at claim.

pub fn issuer(&self) -> Option<String>

Get the issuer claim.

pub fn jti(&self) -> Option<String>

Get the JWT ID claim.

pub fn nonce(&self) -> Option<String>

Get the nonce claim.

pub fn subject(&self) -> Option<String>

Get the subject claim.

pub fn has_claim(&self, name: &str) -> bool

Check if a specific claim exists.

pub fn get_claim<T>(&self, name: &str) -> Option<T>
where T: ValueRetrieval,

Get a specific claim by name with type conversion.

pub fn has_header(&self, name: &str) -> bool

Check if a specific header exists.

pub fn get_header(&self, name: &str) -> Option<String>

Get a specific header by name as string.

pub fn to_serde(&self) -> Result<Value, JWTError>

Serialize the claims to a Value.

pub fn get_claims(&self) -> Value

Get all JWT claims as PDK script value.

pub fn get_headers(&self) -> Value

Get all JWT headers as PDK script value.