SignatureValidator

Struct SignatureValidator 

pub struct SignatureValidator { /* private fields */ }
Main signature validator implementation. It receives the specifications of the signature check:

  • Algorithm
  • Key Length
  • Verifying Key (RSA, ES) or Signing Secret (HMAC)

And it generates the corresponding specific validator for the use case.

Implementations

Source

impl SignatureValidator

pub fn new( algorithm: SigningAlgorithm, key_length: SigningKeyLength, key: String, ) -> Result<Self, JWTError>

Create a new SignatureValidator from the given algorithm, key length and key.

pub fn validate(&self, token: String) -> Result<JWTClaims, JWTError>

Validate a JWT token.