pub struct SignatureValidator { /* private fields */ }Expand description
Main signature validator implementation. It receives the specifications of the signature check:
- Algorithm
- Key Length
- Verifying Key (RSA, ES) or Signing Secret (HMAC)
And it generates the corresponding specific validator for the use case.
Implementations
Sourceimpl SignatureValidator
impl SignatureValidator
Sourcepub fn new(
algorithm: SigningAlgorithm,
key_length: SigningKeyLength,
key: String,
) -> Result<Self, JWTError>
pub fn new( algorithm: SigningAlgorithm, key_length: SigningKeyLength, key: String, ) -> Result<Self, JWTError>
Create a new SignatureValidator from the given algorithm, key length and key.